# 1A1B

## wordindex

### 测试分词模式punctuation

#### #1

nlp=wordindex(char_level=False,punctuation='concise',num_words=1000,max_length=100)

![wordindex](https://github.com/404notf0und/Always-Learning/blob/master/images/wordindex-punctuation-concise.png)

#### #2

nlp=wordindex(char_level=False,punctuation='all',num_words=1000,max_length=100)

![image-20200411194839295](https://github.com/404notf0und/Always-Learning/blob/master/images/image-20200411194839295.png)



#### #3

nlp=wordindex(char_level=False,punctuation='define',num_words=1000,max_length=100)

![image-20200411200245996](https://github.com/404notf0und/Always-Learning/blob/master/images/image-20200411200245996.png)

## word2vec

### 测试预训练数据类别one_class

#### #1

nlp=word2vec(one_class=False,tunning=True,num_words=1000,max_length=100,punctuation='concise')

![word2vec](https://github.com/404notf0und/Always-Learning/blob/master/images/word2vec-tunning-true.png)

#### #2

nlp=word2vec(one_class=True,tunning=True,num_words=1000,max_length=100,punctuation='concise')

![image-20200411195154325](https://github.com/404notf0und/Always-Learning/blob/master/images/image-20200411195154325.png)

#### #3

nlp=word2vec(one_class=False,tunning=True,num_words=3000,max_length=100,punctuation='concise')

![image-20200411201531030](https://github.com/404notf0und/Always-Learning/blob/master/images/image-20200411201531030.png)

#### #4

nlp=word2vec(one_class=True,tunning=True,num_words=3000,max_length=100,punctuation='concise')

![image-20200411201104757](https://github.com/404notf0und/Always-Learning/blob/master/images/image-20200411201104757.png)

#### #5

nlp=word2vec(one_class=False,tunning=True,num_words=None,max_length=100,punctuation='concise')

![image-20200411202023220](https://github.com/404notf0und/Always-Learning/blob/master/images/image-20200411202023220.png)

#### #6

nlp=word2vec(one_class=True,tunning=True,num_words=None,max_length=100,punctuation='concise')

![image-20200411202257266](https://github.com/404notf0und/Always-Learning/blob/master/images/image-20200411202257266.png)

### 测试分词模式punctuation

#### #1

nlp=word2vec(one_class=True,tunning=True,num_words=1000,max_length=100,punctuation='concise')

其他参数：out_dimension=3，vocabulary_size=None

![image-20200411204352334](https://github.com/404notf0und/Always-Learning/blob/master/images/image-20200411204352334.png)

#### #2

tunning=True，punctuation='all'

![image-20200411205601703](https://github.com/404notf0und/Always-Learning/blob/master/images/image-20200411205601703.png)

#### #3

tunning=True，punctuation='define'（加载的xss分词模式）

![image-20200411210001198](https://github.com/404notf0und/Always-Learning/blob/master/images/image-20200411210001198.png)

#### #4

nlp=word2vec(one_class=False,tunning=True,num_words=1000,max_length=100,punctuation='all')

![image-20200411211340391](https://github.com/404notf0und/Always-Learning/blob/master/images/image-20200411211340391.png)

### 测试微调tunning

#### #1

nlp=word2vec(one_class=False,tunning=False,num_words=1000,max_length=100,punctuation='concise')

![word2vec](https://github.com/404notf0und/Always-Learning/blob/master/images/word2vec-tunning-false.png)

#### #2

nlp=word2vec(one_class=False,tunning=True,num_words=1000,max_length=100,punctuation='concise')

![word2vec](https://github.com/404notf0und/Always-Learning/blob/master/images/word2vec-tunning-true.png)

# 3A_A 3A_B

## wordindex

### 测试同源数据

#### #1

nlp=wordindex(char_level=True)

![wordindex-gen](https://github.com/404notf0und/Always-Learning/blob/master/images/wordindex-generalization.png)

# 4A

## wordindex

### 测试多分类

#### #1·

nlp=wordindex(char_level=True)

![wordindex-gen](https://github.com/404notf0und/Always-Learning/blob/master/images/wordindex-multiclass.png)